@@ -11,7 +11,6 @@
 #ifndef HELPMENU_H
 #define HELPMENU_H
 
-#include <QAction>
 #include <QMenu>
 
 class HelpMenu: public QMenu
@@ -25,9 +24,5 @@ public:
 protected slots:
 void onAboutActionTriggered();
 void onAboutQtActionTriggered();
-
-private:
-    QAction aboutaction;
-    QAction aboutqtaction;
 };
 #endif
